@@ -14,16 +14,18 @@ import (
 func TestDialerAddr(t *testing.T) {
 	t.Parallel()
 	dialer := NewDialer(net.Dialer{}, newResolver())
-	dialer.Hosts = map[string]*lib.HostAddress{
-		"example.com":                {IP: net.ParseIP("3.4.5.6")},
-		"example.com:443":            {IP: net.ParseIP("3.4.5.6"), Port: 8443},
-		"example.com:8080":           {IP: net.ParseIP("3.4.5.6"), Port: 9090},
-		"example-deny-host.com":      {IP: net.ParseIP("8.9.10.11")},
-		"example-ipv6.com":           {IP: net.ParseIP("2001:db8::68")},
-		"example-ipv6.com:443":       {IP: net.ParseIP("2001:db8::68"), Port: 8443},
-		"example-ipv6-deny-host.com": {IP: net.ParseIP("::1")},
-	}
-
+	hosts, err := types.NewHosts(
+		map[string]types.Host{
+			"example.com":                {IP: net.ParseIP("3.4.5.6")},
+			"example.com:443":            {IP: net.ParseIP("3.4.5.6"), Port: 8443},
+			"example.com:8080":           {IP: net.ParseIP("3.4.5.6"), Port: 9090},
+			"example-deny-host.com":      {IP: net.ParseIP("8.9.10.11")},
+			"example-ipv6.com":           {IP: net.ParseIP("2001:db8::68")},
+			"example-ipv6.com:443":       {IP: net.ParseIP("2001:db8::68"), Port: 8443},
+			"example-ipv6-deny-host.com": {IP: net.ParseIP("::1")},
+		})
+	require.NoError(t, err)
+	dialer.Hosts = hosts
 	ipNet, err := lib.ParseCIDR("8.9.10.0/24")
 	require.NoError(t, err)
 
@@ -75,9 +77,11 @@ func TestDialerAddr(t *testing.T) {
 func TestDialerAddrBlockHostnamesStar(t *testing.T) {
 	t.Parallel()
 	dialer := NewDialer(net.Dialer{}, newResolver())
-	dialer.Hosts = map[string]*lib.HostAddress{
+	hosts, err := types.NewHosts(map[string]types.Host{
 		"example.com": {IP: net.ParseIP("3.4.5.6")},
-	}
+	})
+	require.NoError(t, err)
+	dialer.Hosts = hosts
 
 	blocked, err := types.NewHostnameTrie([]string{"*"})
 	require.NoError(t, err)
@@ -109,6 +113,32 @@ func TestDialerAddrBlockHostnamesStar(t *testing.T) {
 	}
 }
 
+// Benchmarks /etc/hosts like hostname mapping
+func BenchmarkDialerHosts(b *testing.B) {
+	hosts, err := types.NewHosts(map[string]types.Host{
+		"k6.io":                {IP: []byte("192.168.1.1"), Port: 80},
+		"specific.k6.io":       {IP: []byte("192.168.1.2"), Port: 80},
+		"grafana.com":          {IP: []byte("aa::ff"), Port: 80},
+		"specific.grafana.com": {IP: []byte("aa:bb:::ff"), Port: 80},
+	})
+	require.NoError(b, err)
+
+	dialer := Dialer{
+		Dialer: net.Dialer{},
+		Hosts:  hosts,
+	}
+
+	tcs := []string{"k6.io", "specific.k6.io", "grafana.com", "specific.grafana.com", "not.exists.com"}
+
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		for _, tc := range tcs {
+			//nolint:gosec,errcheck
+			dialer.getDialAddr(tc)
+		}
+	}
+}
+
 func newResolver() *mockresolver.MockResolver {
 	return mockresolver.New(
 		map[string][]net.IP{
