@@ -4,10 +4,14 @@ import (
 	"time"
 
 	"github.com/sirupsen/logrus"
+	"go.k6.io/k6/metrics"
 	"go.k6.io/k6/output"
 )
 
-const collectRate = 50 * time.Millisecond
+const (
+	collectRate          = 50 * time.Millisecond
+	timeSeriesFirstLimit = 100_000
+)
 
 var _ output.Output = &outputIngester{}
 
@@ -24,6 +28,7 @@ type outputIngester struct {
 
 	metricsEngine   *MetricsEngine
 	periodicFlusher *output.PeriodicFlusher
+	cardinality     *cardinalityControl
 }
 
 // Description returns a human-readable description of the output.
@@ -92,6 +97,60 @@ func (oi *outputIngester) flushMetrics() {
 				oi.metricsEngine.markObserved(sm.Metric)
 				sm.Metric.Sink.Add(sample)
 			}
+
+			oi.cardinality.Add(sample.TimeSeries)
 		}
 	}
+
+	if oi.cardinality.LimitHit() {
+		// TODO: suggest using the Metadata API as an alternative, once it's
+		// available (e.g. move high-cardinality tags as Metadata)
+		// https://github.com/grafana/k6/issues/2766
+
+		oi.logger.Warnf(
+			"The test has generated metrics with %d unique time series, "+
+				"which is higher than the suggested limit of %d "+
+				"and could cause high memory usage. "+
+				"Consider not using high-cardinality values like unique IDs as metric tags "+
+				"or, if you need them in the URL, use the name metric tag or URL grouping. "+
+				"See https://k6.io/docs/using-k6/tags-and-groups for details.", oi.cardinality.Count(), timeSeriesFirstLimit)
+	}
+}
+
+type cardinalityControl struct {
+	seen            map[metrics.TimeSeries]struct{}
+	timeSeriesLimit int
+}
+
+func newCardinalityControl() *cardinalityControl {
+	return &cardinalityControl{
+		timeSeriesLimit: timeSeriesFirstLimit,
+		seen:            make(map[metrics.TimeSeries]struct{}),
+	}
+}
+
+// Add adds the passed time series to the list of seen items.
+func (cc *cardinalityControl) Add(ts metrics.TimeSeries) {
+	if _, ok := cc.seen[ts]; ok {
+		return
+	}
+	cc.seen[ts] = struct{}{}
+}
+
+// LimitHit checks if the cardinality limit has been hit.
+func (cc *cardinalityControl) LimitHit() bool {
+	if len(cc.seen) <= cc.timeSeriesLimit {
+		return false
+	}
+
+	// we don't care about overflow
+	// the process should be already OOM
+	// if the number of generated time series goes higher than N-hundred-million(s).
+	cc.timeSeriesLimit *= 2
+	return true
+}
+
+// Count returns the number of distinct seen time series.
+func (cc *cardinalityControl) Count() int {
+	return len(cc.seen)
 }
