@@ -5,7 +5,7 @@ import (
 	"compress/gzip"
 	"encoding/csv"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"sort"
 	"strings"
 	"testing"
@@ -116,6 +116,90 @@ func TestSampleToRow(t *testing.T) {
 			ignoredTags: []string{"tag4", "tag6"},
 			timeFormat:  "rfc3339",
 		},
+		{
+			testname: "Two res tags, two ignored, with Unix Nano timestamp",
+			sample: &metrics.Sample{
+				TimeSeries: metrics.TimeSeries{
+					Metric: testMetric,
+					Tags: registry.RootTagSet().WithTagsFromMap(map[string]string{
+						"tag1": "val1",
+						"tag2": "val2",
+						"tag3": "val3",
+						"tag4": "val4",
+						"tag5": "val5",
+						"tag6": "val6",
+					}),
+				},
+				Time:  time.Unix(1562324644, 25),
+				Value: 1,
+			},
+			resTags:     []string{"tag1", "tag3"},
+			ignoredTags: []string{"tag4", "tag6"},
+			timeFormat:  "unix_nano",
+		},
+		{
+			testname: "Two res tags, two ignored, with Unix Micro timestamp",
+			sample: &metrics.Sample{
+				TimeSeries: metrics.TimeSeries{
+					Metric: testMetric,
+					Tags: registry.RootTagSet().WithTagsFromMap(map[string]string{
+						"tag1": "val1",
+						"tag2": "val2",
+						"tag3": "val3",
+						"tag4": "val4",
+						"tag5": "val5",
+						"tag6": "val6",
+					}),
+				},
+				Time:  time.Unix(1562324644, 2125),
+				Value: 1,
+			},
+			resTags:     []string{"tag1", "tag3"},
+			ignoredTags: []string{"tag4", "tag6"},
+			timeFormat:  "unix_micro",
+		},
+		{
+			testname: "Two res tags, two ignored, with Unix Milli timestamp",
+			sample: &metrics.Sample{
+				TimeSeries: metrics.TimeSeries{
+					Metric: testMetric,
+					Tags: registry.RootTagSet().WithTagsFromMap(map[string]string{
+						"tag1": "val1",
+						"tag2": "val2",
+						"tag3": "val3",
+						"tag4": "val4",
+						"tag5": "val5",
+						"tag6": "val6",
+					}),
+				},
+				Time:  time.Unix(1562324644, 6482125),
+				Value: 1,
+			},
+			resTags:     []string{"tag1", "tag3"},
+			ignoredTags: []string{"tag4", "tag6"},
+			timeFormat:  "unix_milli",
+		},
+		{
+			testname: "Two res tags, two ignored, with RFC3339Nano timestamp",
+			sample: &metrics.Sample{
+				TimeSeries: metrics.TimeSeries{
+					Metric: testMetric,
+					Tags: registry.RootTagSet().WithTagsFromMap(map[string]string{
+						"tag1": "val1",
+						"tag2": "val2",
+						"tag3": "val3",
+						"tag4": "val4",
+						"tag5": "val5",
+						"tag6": "val6",
+					}),
+				},
+				Time:  time.Unix(1562324644, 0),
+				Value: 1,
+			},
+			resTags:     []string{"tag1", "tag3"},
+			ignoredTags: []string{"tag4", "tag6"},
+			timeFormat:  "rfc3339_nano",
+		},
 	}
 
 	expected := []struct {
@@ -160,6 +244,58 @@ func TestSampleToRow(t *testing.T) {
 				"tag5=val5",
 			},
 		},
+		{
+			baseRow: []string{
+				"my_metric",
+				"1562324644000000025",
+				"1.000000",
+				"val1",
+				"val3",
+			},
+			extraRow: []string{
+				"tag2=val2",
+				"tag5=val5",
+			},
+		},
+		{
+			baseRow: []string{
+				"my_metric",
+				"1562324644000002",
+				"1.000000",
+				"val1",
+				"val3",
+			},
+			extraRow: []string{
+				"tag2=val2",
+				"tag5=val5",
+			},
+		},
+		{
+			baseRow: []string{
+				"my_metric",
+				"1562324644006",
+				"1.000000",
+				"val1",
+				"val3",
+			},
+			extraRow: []string{
+				"tag2=val2",
+				"tag5=val5",
+			},
+		},
+		{
+			baseRow: []string{
+				"my_metric",
+				time.Unix(1562324644, 0).Format(time.RFC3339Nano),
+				"1.000000",
+				"val1",
+				"val3",
+			},
+			extraRow: []string{
+				"tag2=val2",
+				"tag5=val5",
+			},
+		},
 	}
 
 	for i := range testData {
@@ -201,7 +337,7 @@ func readCompressedFile(fileName string, fs afero.Fs) string {
 		return err.Error()
 	}
 
-	csvbytes, err := ioutil.ReadAll(gzf)
+	csvbytes, err := io.ReadAll(gzf)
 	if err != nil {
 		return err.Error()
 	}
