@@ -66,19 +66,26 @@ type WithThresholds interface {
 	SetThresholds(map[string]metrics.Thresholds)
 }
 
-// WithTestRunStop is an output that can stop the Engine mid-test, interrupting
-// the whole test run execution if some internal condition occurs, completely
-// independently from the thresholds. It requires a callback function which
-// expects an error and triggers the Engine to stop.
+// WithTestRunStop is an output that can stop the test run mid-way through,
+// interrupting the whole test run execution if some internal condition occurs,
+// completely independently from the thresholds. It requires a callback function
+// which expects an error and triggers the Engine to stop.
 type WithTestRunStop interface {
 	Output
 	SetTestRunStopCallback(func(error))
 }
 
-// WithRunStatusUpdates means the output can receive test run status updates.
-type WithRunStatusUpdates interface {
+// WithStopWithTestError allows output to receive the error value that the test
+// finished with. It could be nil, if the test finished normally.
+//
+// If this interface is implemented by the output, StopWithError() will be
+// called instead of Stop().
+//
+// TODO: refactor the main interface to use this method instead of Stop()? Or
+// something else along the lines of https://github.com/grafana/k6/issues/2430 ?
+type WithStopWithTestError interface {
 	Output
-	SetRunStatus(latestStatus lib.RunStatus)
+	StopWithTestError(testRunErr error) error // nil testRunErr means error-free test run
 }
 
 // WithBuiltinMetrics means the output can receive the builtin metrics.
